@@ -8,7 +8,7 @@ from pathlib import Path
 
 import redis
 import requests
-from BaseColor.base_colors import blue, hcyan
+from BaseColor.base_colors import blue, hcyan, green
 
 
 def tell_the_datetime(time_stamp=None, compact_mode=False):
@@ -99,7 +99,7 @@ def gen_server_script(local_path):
         wf.write(n_rsf)
 
 
-def start_up_check():
+def start_up_check(dont_ask=False):
     if os.path.exists("/etc/init.d/nettrarec"):
         return
     local_path = os.path.split(os.path.abspath(__file__))[0]
@@ -107,8 +107,17 @@ def start_up_check():
     os.popen(
         f'sudo cp {os.path.join(local_path, "nettrarec")} /etc/init.d/ && sudo chmod +x /etc/init.d/nettrarec').read()
     print("It looks like the first run")
-    do = input("you want to add the netrec to system service(it will not show again)? [y/n]: ").lower() or 'n'
+    if dont_ask:
+        do = 'y'
+    else:
+        do = input("you want to add the netrec to system service(it will not show again)? [y/n]: ").lower() or 'n'
     if do == 'y':
+        print("adding nettrarec to system service")
+        os.popen(
+            'chkconfig --add nettrarec && chkconfig nettrarec on && systemctl start nettrarec'
+        ).read()
+        print(green("\nnettrarec has add to system service and set to start automatically at system boot\n"))
+
         print("please run the following steps: ")
         print(blue("1. push target redis info to local redis(replace the XXX to your info): "))
         print("   $", hcyan("redis-cli"))
@@ -116,12 +125,12 @@ def start_up_check():
         print("   127.0.0.1:6379>", hcyan(
             """rpush NetRec_key_params '{"host": "xxx.xxx.xxx.xxx", "port": 6379, "db": 0, "password": "xxxxxx", "insert_key": "xxxxx"}'"""))
 
-        print(blue("2. add system service and set to start automatically at system boot: "))
-        print("   $", hcyan("chkconfig --add nettrarec"))
-        print("   $", hcyan("chkconfig nettrarec on"))
-        print("   $", hcyan("systemctl start nettrarec"))
+        # print(blue("2. add system service and set to start automatically at system boot: "))
+        # print("   $", hcyan("chkconfig --add nettrarec"))
+        # print("   $", hcyan("chkconfig nettrarec on"))
+        # print("   $", hcyan("systemctl start nettrarec"))
 
-        print(blue("3. Open target Redis to check if the data is correct\n"))
+        print(blue("2. Open target Redis to check if the data is correct\n"))
 
 
 def _get_host_name():
